@@ -5,12 +5,12 @@ use warnings;
 
 use Carp;
 use Clone::Choose 0.008;
-use Scalar::Util qw(blessed reftype);
+use Scalar::Util qw(blessed);
 
 use base 'Exporter';
 our $CONTEXT;
 
-our $VERSION     = '0.298';
+our $VERSION     = '0.300';
 our @EXPORT_OK   = qw( merge _hashify _merge_hashes );
 our %EXPORT_TAGS = ('custom' => [qw( _hashify _merge_hashes )]);
 
@@ -145,7 +145,7 @@ sub get_behavior
     return $self->{'behavior'};
 }
 
-sub specify_behavior
+sub add_behavior_spec
 {
     my $self = &_get_obj;    # '&' + no args modifies current @_
     my ($matrix, $name) = @_;
@@ -174,6 +174,19 @@ sub specify_behavior
     $self->{'behaviors'}{$name} = $self->{'matrix'} = $matrix;
 }
 
+no strict "refs";
+*specify_behavior = \&add_behavior_spec;
+use strict;
+
+sub get_behavior_spec
+{
+    my $self = &_get_obj;    # '&' + no args modifies current @_
+    my ($name) = @_;
+    $name ||= 'user defined';
+    exists $self->{'behaviors'}{$name} and return $self->{'behaviors'}{$name};
+  return:
+}
+
 sub set_clone_behavior
 {
     my $self     = &_get_obj;          # '&' + no args modifies current @_
@@ -198,10 +211,10 @@ sub merge
     # of all data that is merged.  This behavior can be shut off, but
     # can create havoc if references are used heavily.
 
-    my $lefttype = reftype($left);
+    my $lefttype = ref($left);
     $lefttype = "SCALAR" unless defined $lefttype and defined $self->{'matrix'}->{$lefttype};
 
-    my $righttype = reftype($right);
+    my $righttype = ref($right);
     $righttype = "SCALAR" unless defined $righttype and defined $self->{'matrix'}->{$righttype};
 
     if ($self->{'clone'})
@@ -305,6 +318,13 @@ __END__
 
 Hash::Merge - Merges arbitrarily deep hashes into a single hash
 
+=begin html
+
+<a href="https://travis-ci.org/perl5-utils/Hash-Merge"><img src="https://travis-ci.org/perl5-utils/Hash-Merge.svg?branch=master" alt="Travis CI"/></a>
+<a href='https://coveralls.io/github/perl5-utils/Hash-Merge?branch=master'><img src='https://coveralls.io/repos/github/perl5-utils/Hash-Merge/badge.svg?branch=master' alt='Coverage Status'/></a>
+
+=end html
+
 =head1 SYNOPSIS
 
     my %a = (
@@ -324,7 +344,7 @@ Hash::Merge - Merges arbitrarily deep hashes into a single hash
     
     # This is the same as above
     
-    Hash::Merge::specify_behavior(
+    Hash::Merge::add_behavior_spec(
         {   'SCALAR' => {
                 'SCALAR' => sub { $_[1] },
                 'ARRAY'  => sub { [ $_[0], @{ $_[1] } ] },
@@ -346,12 +366,24 @@ Hash::Merge - Merges arbitrarily deep hashes into a single hash
     
     # Also there is OO interface.
     
-    my $merge = Hash::Merge->new('LEFT_PRECEDENT');
-    my %c = %{ $merge->merge( \%a, \%b ) };
+    my $merger = Hash::Merge->new('LEFT_PRECEDENT');
+    my %c = %{ $merger->merge( \%a, \%b ) };
     
     # All behavioral changes (e.g. $merge->set_behavior(...)), called on an object remain specific to that object
     # The legacy "Global Setting" behavior is respected only when new called as a non-OO function.
 
+    # re-use globally specified behavior
+    my $merger = Hash::Merge->new();
+    $merger->add_behavior_spec(Hash::Merge::get_behavior_spec("My Behavior"), "My Behavior");
+    my %c = %{ $merger->merge( \%a, \%b ) };
+
+    # re-use externally specified behavior
+    use Hash::Merge::Extra ();
+    my $merger = Hash::Merge->new();
+    $merger->add_behavior_spec(Hash::Merge::Extra::L_REPLACE, "L_REPLACE");
+    my %c = %{ $merger->merge( \%a, \%b ) };
+
+
 =head1 DESCRIPTION
 
 Hash::Merge merges two arbitrarily deep hashes into a single hash.  That
@@ -385,8 +417,8 @@ attempted.
 
     my $merge = Hash::Merge->new();
     my $merge = Hash::Merge->new('LEFT_PRECEDENT');
-    $merge->set_set_behavior('LEFT_PRECEDENT');
-    Hash::Merge::set_set_behavior('LEFT_PRECEDENT');
+    $merge->set_behavior('LEFT_PRECEDENT');
+    Hash::Merge::set_behavior('LEFT_PRECEDENT');
 
 =item Right Precedence
 
@@ -394,8 +426,8 @@ Same as Left Precedence, but with the right
 hash values never being lost
 
     my $merge = Hash::Merge->new('RIGHT_PRECEDENT');
-    $merge->set_set_behavior('RIGHT_PRECEDENT');
-    Hash::Merge::set_set_behavior('RIGHT_PRECEDENT');
+    $merge->set_behavior('RIGHT_PRECEDENT');
+    Hash::Merge::set_behavior('RIGHT_PRECEDENT');
 
 =item Storage Precedence
 
@@ -405,8 +437,8 @@ scalars, hashes over either.  The other medium will try to be fitted in
 the other, but if this isn't possible, the data is dropped.
 
     my $merge = Hash::Merge->new('STORAGE_PRECEDENT');
-    $merge->set_set_behavior('STORAGE_PRECEDENT');
-    Hash::Merge::set_set_behavior('STORAGE_PRECEDENT');
+    $merge->set_behavior('STORAGE_PRECEDENT');
+    Hash::Merge::set_behavior('STORAGE_PRECEDENT');
 
 =item Retainment Precedence
 
@@ -415,8 +447,8 @@ with arrays, and scalars and arrays will be 'hashified' to fit them into
 a hash.
 
     my $merge = Hash::Merge->new('RETAINMENT_PRECEDENT');
-    $merge->set_set_behavior('RETAINMENT_PRECEDENT');
-    Hash::Merge::set_set_behavior('RETAINMENT_PRECEDENT');
+    $merge->set_behavior('RETAINMENT_PRECEDENT');
+    Hash::Merge::set_behavior('RETAINMENT_PRECEDENT');
 
 =back
 
@@ -460,9 +492,13 @@ must be one of those given below.
 
 Returns the behavior that is currently in use by Hash::Merge.
 
-=item specify_behavior( <hashref>, [<name>] )
+=item specify_behavior( <hashref>, [<name>] ) [deprecated]
 
-Specify a custom merge behavior for Hash::Merge.  This must be a hashref
+Alias for C<add_behavior_spec>.
+
+=item add_behavior_spec( <hashref>, [<name>] )
+
+Add a custom merge behavior spec for Hash::Merge.  This must be a hashref
 defined with (at least) 3 keys, SCALAR, ARRAY, and HASH; each of those
 keys must have another hashref with (at least) the same 3 keys defined.
 Furthermore, the values in those hashes must be coderefs.  These will be
@@ -478,6 +514,13 @@ behavior specification include:
 Note that you can import _hashify and _merge_hashes into your program's
 namespace with the 'custom' tag.
 
+=item get_behavior_spec( [<name>] )
+
+Return a previously defined merge behavior spec. If name ism't specified,
+the same default as add_behavior_spec is applied.
+
+If no such name is known referring to an behavior spec, nothing is returned.
+
 =back
 
 =head1 BUILT-IN BEHAVIORS
